package core.notevault.sync.auth;

import android.content.Context;
import android.content.SharedPreferences;
import core.notevault.sync.ApiClient;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class AuthRepository {
    private final AuthService authService;
    private final SharedPreferences preferences;

    public AuthRepository(Context context) {
        this.authService = ApiClient.getRetrofitInstance(context).create(AuthService.class);
        this.preferences = context.getSharedPreferences("app_prefs", Context.MODE_PRIVATE);
    }

    public void performLogin(String username, String password, LoginCallback callback) {
        LoginRequest loginRequest = new LoginRequest(username, password);

        authService.login(loginRequest).enqueue(new Callback<LoginResponse>() {
            @Override
            public void onResponse(Call<LoginResponse> call, Response<LoginResponse> response) {
                if (response.isSuccessful() && response.body() != null) {
                    String token = response.body().getToken();
                    saveToken(token);

                    // Erfolgsrückmeldung an den Callback senden
                    callback.onSuccess();
                } else {
                    // Fehlermeldung an den Callback senden
                    callback.onError("Login fehlgeschlagen. Überprüfe Benutzername und Passwort.");
                }
            }

            @Override
            public void onFailure(Call<LoginResponse> call, Throwable t) {
                // Netzwerkfehler an den Callback senden
                callback.onError("Netzwerkfehler: " + t.getMessage());
            }
        });
    }

    private void saveToken(String token) {
        SharedPreferences.Editor editor = preferences.edit();
        editor.putString("jwt_token", token);
        editor.apply();
    }
}
